@@ -6,7 +6,7 @@
 #' @examples
 #' league_members(leagueId = "42654852")
 #' @return A dataframe (or list) with league members.
-#' @family League information
+#' @family league functions
 #' @export
 league_members <- function(leagueId = ffl_id(), leagueHistory = FALSE, ...) {
   dat <- ffl_api(
@@ -16,8 +16,13 @@ league_members <- function(leagueId = ffl_id(), leagueHistory = FALSE, ...) {
   )
   if (leagueHistory && is.list(dat$teams)) {
     names(dat$teams) <- dat$seasonId
-    lapply(dat$members, as_tibble)
+    lapply(dat$members, out_member)
   } else {
-    as_tibble(dat$members)
+    out_member(dat$members)
   }
 }
+
+out_member <- function(x) {
+  x <- change_names(x, "id", "memberId")
+  as_tibble(x)
+}
