@@ -74,7 +74,7 @@ list_players <- function(leagueId = ffl_id(),
     verb = "GET",
     url = paste0(
       "https://fantasy.espn.com",
-      "/apis/v3/games/ffl/seasons/2021/segments/0/leagues/",
+      "/apis/v3/games/ffl/seasons/2022/segments/0/leagues/",
       leagueId
     ),
     query = list(view = "kona_player_info"),
@@ -126,9 +126,9 @@ list_players <- function(leagueId = ffl_id(),
     if (length(unique(s$scoringPeriodId)) < 3) {
       next # player doesn't have stats from last week
     }
-    if (sum(s$seasonId == y - 1) > 1) {
-      next # player has more than one from previous season
-    }
+    # if (sum(s$seasonId == y - 1) > 1) {
+    #   next # player has more than one from previous season
+    # }
     w <- max(s$scoringPeriodId[s$seasonId == y])
     w_last <- which(s$statSourceId == 0 &
                       s$statSplitTypeId == 1 &
@@ -148,7 +148,14 @@ list_players <- function(leagueId = ffl_id(),
     }
     z$currentSeason[i] <- s$appliedTotal[s$id == paste0("00", y)]
     if (length(unique(s$seasonId)) > 1) {
-      z$lastSeason[i] <- s$appliedTotal[s$id == paste0("00", y - 1)]
+      which_last <- which(s$id == paste0("00", y - 1))
+      if (length(which_last) < 1) {
+        z$lastSeason[i] <- NA_real_
+      } else {
+        z$lastSeason[i] <- s$appliedTotal[which_last]
+      }
+    } else {
+      z$lastSeason[i] <- NA_real_
     }
   }
   out <- as_tibble(pl$player)
@@ -253,11 +260,11 @@ fantasy_filter <- function(sort, position, status, injured, scoringPeriodId,
       filterStatsForTopScoringPeriodIds = list(
         value = U(2),
         additionalValue = c(
-          "002021",
-          "102021",
+          "002022",
+          "102022",
           "002020",
-          paste0("112021", scoringPeriodId),
-          "022021"
+          paste0("112022", scoringPeriodId),
+          "022022"
         )
       )
     )
@@ -307,7 +314,7 @@ filter_sort <- function(sort = "ROST", scoringPeriodId) {
     sortAppliedStatTotal = list( # PROJ
       sortAsc = FALSE,
       sortPriority = 1,
-      value = paste0("112021", scoringPeriodId)
+      value = paste0("112022", scoringPeriodId)
     ),
     sortAppliedStatTotalForScoringPeriodId = list( # SCORE
       sortAsc = FALSE,
@@ -339,12 +346,12 @@ filter_sort <- function(sort = "ROST", scoringPeriodId) {
     sortAppliedStatTotal = list( # FPTS
       sortAsc = FALSE,
       sortPriority = 1,
-      value = "002021"
+      value = "002022"
     ),
     sortAppliedStatAverage = list( # AVG
       sortAsc = FALSE,
       sortPriority = 1,
-      value = "002021"
+      value = "002022"
     ),
     sortAppliedStatTotalForScoringPeriodId = list( # LAST
       sortAsc = FALSE,
@@ -393,7 +400,7 @@ player_info <- function(playerId) {
   dat <- try_json(
     url = paste0(
       "http://sports.core.api.espn.com/",
-      "v2/sports/football/leagues/nfl/seasons/2021/athletes/", playerId
+      "v2/sports/football/leagues/nfl/seasons/2022/athletes/", playerId
     )
   )
   out <- list(
